.. Placed this in a separate file so that it only needs to be updated in one place

**Quick getting started and troubleshooting instructions for R users** can be found
in the `RSimpactCyan github repository <https://github.com/j0r1/RSimpactCyan/blob/master/INSTALLATION.md>`_.
